Picket
Picket is a lightweight, serde-compatible generational arena allocator.
It allows you to insert items into an Arena and receive a unique Index in return.
Unlike a standard Vec index, a Picket Index contains a “generation” counter.
If an item is removed and its slot is reused by a new item, the old Index will
fail to access the new item, preventing ABA problems.
Key Features
- Compact:
Indexis 8 bytes.Option<Index>is also 8 bytes. - Serde: Optional support for full serialization/deserialization (feature:
serde). - no_std: Compatible with
no_std.